@@ -23,8 +23,22 @@ async def trigger_event(event: Event, *args) -> list:
 
 
 def event_handler(event: Event):
-    def _func(func):
+    def _register(func):
         custom_event_handlers[event].append(func)
-        return func
+        return AsyncEventWrapper(func, type=event)
 
-    return _func
+    return _register
+
+
+class AsyncEventWrapper:
+    def __init__(self, func, type: Event):
+        self.func = func
+        self.type = type
+
+    def unregister(self):
+        events = custom_event_handlers[self.type]
+        if self.func in events:
+            events.remove(self.func)
+
+    async def __call__(self, *args, **kwargs):
+        await self.func(args, **kwargs)
